@@ -25,10 +25,10 @@
 #include <resources/ResourcesProxyModel.h>
 #include <resources/AbstractBackendUpdater.h>
 #include <ApplicationAddonsModel.h>
-#include <Transaction/TransactionModel.h>
 #include <ReviewsBackend/ReviewsModel.h>
 #include <UpdateModel/UpdateModel.h>
 #include <resources/ResourcesUpdatesModel.h>
+#include <Transaction/TransactionModel.h>
 
 #include <qtest.h>
 #include <QtTest>
@@ -66,6 +66,30 @@ private Q_SLOTS:
         }
     }
 
+    void testInformation()
+    {
+        ResourcesUpdatesModel* rum = new ResourcesUpdatesModel(this);
+        new ModelTest(rum, rum);
+
+        UpdateModel* m = new UpdateModel(this);
+        new ModelTest(m, m);
+        m->setBackend(rum);
+
+        rum->prepare();
+        QSignalSpy spySetup(m_appBackend->backendUpdater(), &AbstractBackendUpdater::progressingChanged);
+        QVERIFY(!m_appBackend->backendUpdater()->isProgressing() || spySetup.wait());
+        QCOMPARE(m_appBackend->updatesCount(), m_appBackend->property("startElements").toInt()*2/3);
+        QCOMPARE(m->hasUpdates(), true);
+
+        QCOMPARE(m->index(0,0).data(UpdateModel::ChangelogRole).toString(), {});
+
+        QSignalSpy spy(m, &QAbstractItemModel::dataChanged);
+        m->fetchChangelog(0);
+        QVERIFY(spy.count() || spy.wait());
+        QCOMPARE(spy.count(), 1);
+        delete m;
+    }
+
     void testUpdate()
     {
         ResourcesUpdatesModel* rum = new ResourcesUpdatesModel(this);
@@ -106,8 +130,29 @@ private Q_SLOTS:
         QCOMPARE(m->hasUpdates(), true);
 
         rum->prepare();
+
+        spy.clear();
+        QCOMPARE(rum->isProgressing(), false);
         rum->updateAll();
-        QVERIFY(spy.wait());
+        QVERIFY(spy.count() || spy.wait());
+        QCOMPARE(rum->isProgressing(), true);
+
+        QCOMPARE(TransactionModel::global()->rowCount(), 1);
+        connect(TransactionModel::global(), &TransactionModel::progressChanged, this, []() {
+            const int progress = TransactionModel::global()->progress();
+            static int lastProgress = -1;
+            Q_ASSERT(progress >= lastProgress || (TransactionModel::global()->rowCount() == 0 && progress == 0));
+            lastProgress = progress;
+        });
+
+        QTest::qWait(20);
+        QScopedPointer<ResourcesUpdatesModel> rum2(new ResourcesUpdatesModel(this));
+        new ModelTest(rum2.data(), rum2.data());
+
+        QScopedPointer<UpdateModel> m2(new UpdateModel(this));
+        new ModelTest(m2.data(), m2.data());
+        m->setBackend(rum2.data());
+
         QCOMPARE(rum->isProgressing(), true);
         QVERIFY(spy.wait());
         QCOMPARE(rum->isProgressing(), false);
