@@ -47,7 +47,7 @@ class PackageKitResource : public AbstractResource
         void fetchChangelog() override;
         
         QList<PackageState> addonsInformation() override;
-        State state() override;
+        State state() const override;
         
         QString installedVersion() const override;
         QString availableVersion() const override;
@@ -67,6 +67,7 @@ class PackageKitResource : public AbstractResource
         bool canExecute() const override { return false; }
 
         QString sizeDescription() override;
+        void setDependenciesCount(uint count);
 
     public Q_SLOTS:
         void addPackageId(PackageKit::Transaction::Info info, const QString &packageId, bool arch);
