@@ -30,6 +30,7 @@ SnapResource::SnapResource(QSharedPointer<QSnapdSnap> snap, AbstractResource::St
     , m_state(state)
     , m_snap(snap)
 {
+    setObjectName(snap->name());
 }
 
 QString SnapResource::availableVersion() const
@@ -49,7 +50,8 @@ QString SnapResource::comment()
 
 int SnapResource::size()
 {
-    return isInstalled() ? m_snap->installedSize() : m_snap->downloadSize();
+//     return isInstalled() ? m_snap->installedSize() : m_snap->downloadSize();
+    return m_snap->downloadSize();
 }
 
 QUrl SnapResource::homepage()
@@ -59,20 +61,31 @@ QUrl SnapResource::homepage()
 
 QVariant SnapResource::icon() const
 {
-    const auto iconPath = m_snap->icon();
-    if (iconPath.isEmpty())
-        return QStringLiteral("package-x-generic");
+    if (m_icon.isNull()) {
+        m_icon = [this]() -> QVariant {
+            const auto iconPath = m_snap->icon();
+            if (iconPath.isEmpty())
+                return QStringLiteral("package-x-generic");
 
-    if (!iconPath.startsWith(QLatin1Char('/')))
-        return QUrl(iconPath);
+            if (!iconPath.startsWith(QLatin1Char('/')))
+                return QUrl(iconPath);
 
-    auto backend = qobject_cast<SnapBackend*>(parent());
-    auto req = backend->client()->getIcon(packageName());
-    req->runSync();
+            auto backend = qobject_cast<SnapBackend*>(parent());
+            auto req = backend->client()->getIcon(packageName());
+            connect(req, &QSnapdGetIconRequest::complete, this, &SnapResource::gotIcon);
+            req->runAsync();
+            return {};
+        }();
+    }
+    return m_icon;
+}
 
+void SnapResource::gotIcon()
+{
+    auto req = qobject_cast<QSnapdGetIconRequest*>(sender());
     if (req->error()) {
-        qWarning() << "icon error" << req->errorString() << iconPath;
-        return {};
+        qWarning() << "icon error" << req->errorString();
+        return;
     }
 
     auto icon = req->icon();
@@ -81,7 +94,11 @@ QVariant SnapResource::icon() const
     buffer.setData(icon->data());
     QImageReader reader(&buffer);
 
-    return QVariant::fromValue<QImage>(reader.read());
+    auto theIcon = QVariant::fromValue<QImage>(reader.read());
+    if (theIcon != m_icon) {
+        m_icon = theIcon;
+        iconChanged();
+    }
 }
 
 QString SnapResource::installedVersion() const
@@ -119,7 +136,7 @@ QString SnapResource::section()
     return QStringLiteral("snap");
 }
 
-AbstractResource::State SnapResource::state()
+AbstractResource::State SnapResource::state() const
 {
     return m_state;
 }
@@ -163,3 +180,15 @@ QUrl SnapResource::url() const
     //FIXME interim, until it has an appstreamId
     return QUrl(QStringLiteral("snap://") + packageName());
 }
+
+void SnapResource::setSnap(const QSharedPointer<QSnapdSnap>& snap)
+{
+    Q_ASSERT(snap->name() == m_snap->name());
+    if (m_snap == snap)
+        return;
+
+    const bool newSize = m_snap->installedSize() != snap->installedSize() || m_snap->downloadSize() != snap->downloadSize();
+    m_snap = snap;
+    if (newSize)
+        Q_EMIT sizeChanged();
+}
