@@ -44,7 +44,7 @@ public:
     int size() override;
     QUrl homepage() override;
     QStringList categories() override;
-    AbstractResource::State state() override;
+    AbstractResource::State state() const override;
     QVariant icon() const override;
     QString comment() override;
     QString name() override;
@@ -56,13 +56,16 @@ public:
     void fetchScreenshots() override;
     QList<PackageState> addonsInformation() override { return {}; }
     QUrl url() const override;
+    void setSnap(const QSharedPointer<QSnapdSnap> &snap);
 
     void setState(AbstractResource::State state);
 
 public:
+    void gotIcon();
     AbstractResource::State m_state;
 
     QSharedPointer<QSnapdSnap> m_snap;
+    mutable QVariant m_icon;
 };
 
 #endif // SNAPRESOURCE_H
